;; Generated package description from embark-consult.el  -*- no-byte-compile: t -*-
(define-package "embark-consult" "0.8" "Consult integration for Embark" '((emacs "27.1") (embark "0.20") (consult "0.17")) :commit "07af44c7de72efde79ac563cbecdfff0b48d8411" :authors '(("Omar Antolín Camarena" . "omar@matem.unam.mx")) :maintainer '("Omar Antolín Camarena" . "omar@matem.unam.mx") :keywords '("convenience") :url "https://github.com/oantolin/embark")
